import * as React from "react";
import PropTypes from "prop-types";
export interface IKakaoMapsMarkerImage {
    src: string;
    size: {
        width: number;
        height: number;
    };
    options: {
        alt?: string;
        coords?: string;
        shape?: string;
        offset?: {
            x: number;
            y: number;
        };
        spriteOrigin?: {
            x: number;
            y: number;
        };
        spriteSize?: {
            width: number;
            height: number;
        };
    };
}
export interface IKakaoMapsMarkerProps {
    className?: string;
    position: {
        lat: number;
        lng: number;
    };
    title?: string;
    clickable?: boolean;
    draggable?: boolean;
    visible?: boolean;
    /** 불투명도 ( 0 ~ 1 ) */
    opacity?: number;
    zIndex?: number;
    /** 단위 : m */
    range?: number;
    /** 단위 : m */
    altitude?: number;
    image?: IKakaoMapsMarkerImage | null;
    onClick?: (e: {
        position: {
            lat: number;
            lng: number;
        };
    }) => void;
    onRightClick?: (e: {
        position: {
            lat: number;
            lng: number;
        };
    }) => void;
    onMouseOver?: (e: {
        position: {
            lat: number;
            lng: number;
        };
    }) => void;
    onMouseOut?: (e: {
        position: {
            lat: number;
            lng: number;
        };
    }) => void;
    onDragStart?: (e: {
        position: {
            lat: number;
            lng: number;
        };
    }) => void;
    onDragEnd?: (e: {
        position: {
            lat: number;
            lng: number;
        };
    }) => void;
}
declare function Marker(props: React.PropsWithChildren<IKakaoMapsMarkerProps>): JSX.Element;
declare namespace Marker {
    var defaultProps: {
        opacity: number;
        visible: boolean;
        range: number;
        zIndex: number;
        altitude: number;
        clickable: boolean;
        draggable: boolean;
    };
    var propTypes: {
        /** 맵에 표시될 좌표 */
        position: PropTypes.Validator<PropTypes.InferProps<{
            lat: PropTypes.Validator<number>;
            lng: PropTypes.Validator<number>;
        }>>;
        /** 기본 마커 대신 사용할 이미지 */
        image: PropTypes.Requireable<PropTypes.InferProps<{
            src: PropTypes.Validator<string>;
            size: PropTypes.Validator<PropTypes.InferProps<{
                width: PropTypes.Validator<number>;
                height: PropTypes.Validator<number>;
            }>>;
            options: PropTypes.Validator<PropTypes.InferProps<{
                alt: PropTypes.Requireable<string>;
                coords: PropTypes.Requireable<string>;
                shape: PropTypes.Requireable<string>;
                offset: PropTypes.Requireable<PropTypes.InferProps<{
                    x: PropTypes.Validator<number>;
                    y: PropTypes.Validator<number>;
                }>>;
                spriteOrigin: PropTypes.Requireable<PropTypes.InferProps<{
                    x: PropTypes.Validator<number>;
                    y: PropTypes.Validator<number>;
                }>>;
                spriteSize: PropTypes.Requireable<PropTypes.InferProps<{
                    width: PropTypes.Validator<number>;
                    height: PropTypes.Validator<number>;
                }>>;
            }>>;
        }>>;
        /** 툴팁 */
        title: PropTypes.Requireable<string>;
        /** 불투명도 ( 0 ~ 1 ) */
        opacity: PropTypes.Requireable<number>;
        /** 드래그 가능 여부 */
        draggable: PropTypes.Requireable<boolean>;
        /** 클릭 가능 여부 */
        clickable: PropTypes.Requireable<boolean>;
        /** 노출 여부 */
        visible: PropTypes.Requireable<boolean>;
        /** z-index 속성 값 */
        zIndex: PropTypes.Requireable<number>;
        /** 표시될 최대 거리 ( 로드맵 only ) */
        range: PropTypes.Requireable<number>;
        /** 고도 ( 로드맵 only ) */
        altitude: PropTypes.Requireable<number>;
        /** (e: { position: { lat: number, lng: number } }) => void */
        onClick: PropTypes.Requireable<(...args: any[]) => any>;
        /** (e: { position: { lat: number, lng: number } }) => void */
        onRightClick: PropTypes.Requireable<(...args: any[]) => any>;
        /** (e: { position: { lat: number, lng: number } }) => void */
        onDragStart: PropTypes.Requireable<(...args: any[]) => any>;
        /** (e: { position: { lat: number, lng: number } }) => void */
        onDragEnd: PropTypes.Requireable<(...args: any[]) => any>;
        /** (e: { position: { lat: number, lng: number } }) => void */
        onMouseOver: PropTypes.Requireable<(...args: any[]) => any>;
        /** (e: { position: { lat: number, lng: number } }) => void */
        onMouseOut: PropTypes.Requireable<(...args: any[]) => any>;
    };
}
export default Marker;
