import * as React from "react";
import PropTypes from "prop-types";
import type { TKakaoStrokeStyles } from "tenel-kakao-map";
export interface IKakaoMapsRectangleProps {
    className?: string;
    /** [SW, NE] */
    bounds: [{
        lat: number;
        lng: number;
    }, {
        lat: number;
        lng: number;
    }];
    fillColor?: string;
    fillOpacity?: number;
    /** 단위 : px */
    strokeWeight?: number;
    strokeColor?: string;
    strokeOpacity?: number;
    strokeStyle?: TKakaoStrokeStyles;
    zIndex?: number;
    onClick?: (e: {
        position: {
            lat: number;
            lng: number;
        };
    }) => void;
    onMouseDown?: (e: {
        position: {
            lat: number;
            lng: number;
        };
    }) => void;
    onMouseMove?: (e: {
        position: {
            lat: number;
            lng: number;
        };
    }) => void;
    onMouseOver?: (e: {
        position: {
            lat: number;
            lng: number;
        };
    }) => void;
    onMouseOut?: (e: {
        position: {
            lat: number;
            lng: number;
        };
    }) => void;
}
declare function Rectangle(props: React.PropsWithChildren<IKakaoMapsRectangleProps>): JSX.Element;
declare namespace Rectangle {
    var defaultProps: {
        fillColor: string;
        fillOpacity: number;
        strokeColor: string;
        strokeWeight: number;
        strokeOpacity: number;
        strokeStyle: string;
        zIndex: number;
    };
    var propTypes: {
        /**
         * bounds[0] : Position ( SW )
         * bounds[1] : Position ( NE )
         */
        bounds: PropTypes.Validator<[PropTypes.InferProps<{
            lat: PropTypes.Validator<number>;
            lng: PropTypes.Validator<number>;
        }>, PropTypes.InferProps<{
            lat: PropTypes.Validator<number>;
            lng: PropTypes.Validator<number>;
        }>]>;
        /** 채움 색 */
        fillColor: PropTypes.Requireable<string>;
        /** 채움 색의 불투명도 ( 0 ~ 1 ) */
        fillOpacity: PropTypes.Requireable<number>;
        /** 선 색 */
        strokeColor: PropTypes.Requireable<string>;
        /** 선 불투명도 ( 0 ~ 1 ) */
        strokeOpacity: PropTypes.Requireable<number>;
        /** 선의 두께 ( 단위 : px ) */
        strokeWeight: PropTypes.Requireable<number>;
        /** 선 스타일 */
        strokeStyle: PropTypes.Requireable<string>;
        /** z-index 속성 값 */
        zIndex: PropTypes.Requireable<number>;
        /** (e: { position: { lat: number, lng: number } }) => void */
        onClick: PropTypes.Requireable<(...args: any[]) => any>;
        /** (e: { position: { lat: number, lng: number } }) => void */
        onMouseDown: PropTypes.Requireable<(...args: any[]) => any>;
        /** (e: { position: { lat: number, lng: number } }) => void */
        onMouseMove: PropTypes.Requireable<(...args: any[]) => any>;
        /** (e: { position: { lat: number, lng: number } }) => void */
        onMouseOver: PropTypes.Requireable<(...args: any[]) => any>;
        /** (e: { position: { lat: number, lng: number } }) => void */
        onMouseOut: PropTypes.Requireable<(...args: any[]) => any>;
    };
}
export default Rectangle;
